Class: TravelTimeAPI::RoutesResult

Inherits:
Struct
  • Object
show all
Defined in:
lib/traveltime_api.rb

Overview

Result of #routes method.

  • RouteDescriptionPart is a structure describing one part of the route: { "mode": EdgeType,

    Array of coordinates for this route part. Can be used to draw a polyline

    on a map.

    "coords": [[lat, lon], [lat, lon], [lat, lon], ...], "directions: String, # textual description in english of this route part "distance": Int, # distance covered in metres for this route part "time": Int # time taken to travel through this route part in seconds }

Instance Attribute Summary collapse

Instance Attribute Details

#routesObject

Returns the value of attribute routes

Returns:

  • (Object)

    the current value of routes



90
91
92
# File 'lib/traveltime_api.rb', line 90

def routes
  @routes
end